@@ -50,7 +50,7 @@
     digest, verbose)
 {
     h <- "."
-    if (.crayon()) h <- crayon::blurred(h)
+    if (.crayon()) h <- crayon::silver(h)
 
     for (i in seq_along(varnm))
     {
@@ -73,8 +73,8 @@
         need <- FALSE
         for (j in seq_along(flist))
         {
-            n <- index.gdsn(flist[[j]],
-                paste("annotation/info/", varnm[i], sep=""), silent=TRUE)
+            n <- index.gdsn(flist[[j]], paste0("annotation/info/", varnm[i]),
+                silent=TRUE)
             if (is.null(n))
             {
                 need <- TRUE
@@ -109,9 +109,11 @@
             if (!is.null(n4))
             {
                 append.gdsn(n2, n4)
+                unload.gdsn(n4)
                 if (!is.null(n5))
                 {
                     append.gdsn(n3, n5)
+                    unload.gdsn(n5)
                 } else {
                     if (!is.null(n3))
                     {
@@ -162,7 +164,7 @@
         if (verbose)
         {
             cat("        ", varnm[i], " ", sep="")
-            cat(if (.crayon()) crayon::blurred("[") else "[")
+            cat(if (.crayon()) crayon::silver("[") else "[")
         }
         idx <- 0L
         for (j in seq_along(flist))
@@ -203,7 +205,7 @@
                 if (verbose)
                 {
                     h <- paste0(ifelse(j > 1L, ",", ""), j)
-                    if (.crayon()) h <- crayon::blurred(h)
+                    if (.crayon()) h <- crayon::silver(h)
                     cat(h)
                     flush(stdout()); flush.console()
                 }
@@ -242,7 +244,7 @@
         readmode.gdsn(n4)
         readmode.gdsn(n5)
         if (verbose)
-            cat(if (.crayon()) crayon::blurred("]") else "]")
+            cat(if (.crayon()) crayon::silver("]") else "]")
         .DigestCode(n4, digest, verbose)
         .DigestCode(n5, digest, FALSE)
 
@@ -1002,10 +1004,11 @@ seqMerge <- function(gds.fn, out.fn, storage.option="LZMA_RA",
 #######################################################################
 # Reset the variant IDs in multiple GDS files
 #
-seqResetVariantID <- function(gds.fn, set=NULL, digest=TRUE, optimize=TRUE,
-    verbose=TRUE)
+seqResetVariantID <- function(gds.fn, start=1L, set=NULL, digest=TRUE,
+    optimize=TRUE, verbose=TRUE)
 {
     stopifnot(is.character(gds.fn), length(gds.fn)>0L)
+    stopifnot(is.numeric(start), length(start)==1L, start>=1L)
     stopifnot(is.null(set) || is.logical(set))
     if (is.logical(set))
         stopifnot(length(gds.fn) == length(set))
@@ -1013,23 +1016,30 @@ seqResetVariantID <- function(gds.fn, set=NULL, digest=TRUE, optimize=TRUE,
     stopifnot(is.logical(optimize), length(optimize)==1L)
     stopifnot(is.logical(verbose), length(verbose)==1L)
 
-    n <- 0L
-    i <- 1L
-    for (k in seq_along(gds.fn))
+    n <- start - 1L
+    for (i in seq_along(gds.fn))
     {
-        fn <- gds.fn[k]
+        fn <- gds.fn[i]
         if (verbose)
             cat(sprintf("[%2d] %s ...", i, fn))
-        i <- i + 1L
         f <- seqOpen(fn, readonly=FALSE)
         dp <- objdesp.gdsn(index.gdsn(f, "variant.id"))
         len <- prod(dp$dim)
-        v <- seq_len(len) + n
-        if (is.null(set) || isTRUE(set[k]))
+        # check integer overflow
+        new_n <- n + as.double(len)
+        stopifnot(is.finite(new_n))
+        if (new_n < .Machine$integer.max)
         {
-            nd <- add.gdsn(f, "variant.id", v, storage="int", compress=dp$compress,
+            v <- seq.int(n+1L, length.out=len)
+            stopifnot(is.integer(v))
+        } else {
+            v <- seq(n+1, length.out=len)
+            stopifnot(is.double(v))
+        }
+        if (is.null(set) || isTRUE(set[i]))
+        {
+            nd <- add.gdsn(f, "variant.id", v, compress=dp$compress,
                 replace=TRUE, closezip=TRUE)
-            n <- n + len
             if (digest)
                 .DigestCode(nd, TRUE, verbose)
             seqClose(f)
@@ -1037,18 +1047,22 @@ seqResetVariantID <- function(gds.fn, set=NULL, digest=TRUE, optimize=TRUE,
                 cleanup.gds(fn, verbose=FALSE)
             if (verbose)
             {
-                cat("    set new variant id: ", v[1L], " ... ", v[length(v)],
-                    " [", length(v), "]\n", sep="")
+                cat("    set new variant id: ",
+                    .pretty(v[1L]), " ... ", .pretty(v[length(v)]),
+                    " [n=", .pretty(length(v)), "]\n", sep="")
             }
         } else {
-            n <- n + len
             seqClose(f)
             if (verbose)
             {
-                cat("\n    skip variant id: ", v[1L], " ... ", v[length(v)],
-                    " [", length(v), "]\n", sep="")
+                cat("\n    skip variant id: ",
+                    .pretty(v[1L]), " ... ", .pretty(v[length(v)]),
+                    " [n=", length(v), "]\n", sep="")
             }
         }
+        # update
+        if (new_n < .Machine$integer.max) new_n <- as.integer(new_n)
+        n <- new_n
     }
 
     invisible()
